export interface Reference {
    $ref: string;
}
export declare function isReference(schema: any): schema is Reference;
export interface JsonSchema {
    deprecated?: boolean;
    description?: string;
    readOnly?: boolean;
    title?: string;
    writeOnly?: boolean;
}
export interface ComposedJsonSchema<T = JsonSchema> {
    allOf?: Array<T>;
    anyOf?: Array<T>;
    not?: T;
    oneOf?: Array<T>;
}
export declare function isComposedJsonSchema(schema: any): schema is ComposedJsonSchema;
export interface NullJsonSchema extends JsonSchema, ComposedJsonSchema<NullJsonSchema> {
    const?: null;
    default?: null;
    enum?: Array<null>;
    examples?: Array<null>;
    type?: 'null' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isNullJsonSchema(schema: any): schema is NullJsonSchema;
export interface BooleanJsonSchema extends JsonSchema, ComposedJsonSchema<BooleanJsonSchema> {
    const?: boolean;
    default?: boolean;
    enum?: Array<boolean>;
    examples?: Array<boolean>;
    type?: 'boolean' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isBooleanJsonSchema(schema: any): schema is BooleanJsonSchema;
export interface StringJsonSchema extends JsonSchema, ComposedJsonSchema<StringJsonSchema> {
    const?: string;
    default?: string;
    enum?: Array<string>;
    examples?: Array<string>;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
    type?: 'string' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isStringJsonSchema(schema: any): schema is StringJsonSchema;
export interface NumberJsonSchema extends JsonSchema, ComposedJsonSchema<NumberJsonSchema> {
    const?: number;
    default?: number;
    enum?: Array<number>;
    examples?: Array<number>;
    exclusiveMaximum?: number;
    exclusiveMinimum?: number;
    maximum?: number;
    minimum?: number;
    multipleOf?: number;
    type?: 'number' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isNumberJsonSchema(schema: any): schema is NumberJsonSchema;
export interface IntegerJsonSchema extends JsonSchema, ComposedJsonSchema<IntegerJsonSchema> {
    const?: number;
    default?: number;
    enum?: Array<number>;
    examples?: Array<number>;
    exclusiveMaximum?: number;
    exclusiveMinimum?: number;
    maximum?: number;
    minimum?: number;
    multipleOf?: number;
    type?: 'integer' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isIntegerJsonSchema(schema: any): schema is IntegerJsonSchema;
export interface ArrayJsonSchema extends JsonSchema, ComposedJsonSchema<ArrayJsonSchema> {
    const?: Array<any>;
    contains?: JsonSchema;
    default?: Array<any>;
    enum?: Array<Array<any>>;
    examples?: Array<Array<any>>;
    items?: JsonSchema;
    maxContains?: number;
    maxItems?: number;
    minContains?: number;
    minItems?: number;
    prefixItems?: Array<JsonSchema>;
    type?: 'array' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
    uniqueItems?: boolean;
}
export declare function isArrayJsonSchema(schema: any): schema is ArrayJsonSchema;
export interface ObjectJsonSchema extends JsonSchema, ComposedJsonSchema<ObjectJsonSchema> {
    additionalProperties?: JsonSchema;
    const?: Record<string, any>;
    default?: Record<string, any>;
    dependentRequired?: Record<string, Array<string>>;
    enum?: Array<Record<string, any>>;
    examples?: Array<Record<string, any>>;
    maxProperties?: number;
    minProperties?: number;
    patternProperties?: {
        [propertyNameRegex: string]: JsonSchema;
    };
    properties?: {
        [propertyName: string]: JsonSchema;
    };
    propertyNames?: JsonSchema;
    required?: Array<string>;
    type?: 'object' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isObjectJsonSchema(schema: any): schema is ObjectJsonSchema;
export interface AnyJsonSchema extends JsonSchema, ComposedJsonSchema {
    additionalProperties?: never;
    const?: any;
    contains?: never;
    default?: any;
    dependentRequired?: never;
    enum?: Array<any>;
    examples?: Array<any>;
    exclusiveMaximum?: never;
    exclusiveMinimum?: never;
    items?: never;
    maxContains?: never;
    maxItems?: never;
    maxLength?: never;
    maxProperties?: never;
    maximum?: never;
    minContains?: never;
    minItems?: never;
    minLength?: never;
    minProperties?: never;
    minimum?: never;
    multipleOf?: never;
    pattern?: never;
    patternProperties?: never;
    prefixItems?: never;
    properties?: never;
    propertyNames?: never;
    required?: never;
    type?: never;
    uniqueItems?: never;
}
//# sourceMappingURL=jsonSchema.d.ts.map